===============================
Icarus Pressure Jump for NMR
===============================

.. image:: https://img.shields.io/pypi/v/icarus-nmr.svg
        :target: https://pypi.python.org/pypi/icarus-nmr

.. image:: https://zenodo.org/badge/212235996.svg
        :target: https://zenodo.org/badge/latestdoi/212235996

Pressure Jump Software for time-resolved pressure NMR

* Free software: 3-clause BSD license
* Documentation: https://vstadnytskyi.github.io/icarus-nmr 

Features
--------

* TODO
